/*
   header file for netmonitor: reduced number & timeout of pings to improve FTP
*/

//for testing with WiFiAccessPoint-Switched
//const char* ssid     = "yourAP";
//const char* pass = "yourPassword";

// to do the pin mapping for the Lolin NodeMCU pins D0 - D8: NOTE D8 LED is connected to GND not +Vcc so logic is reversed
// sequence is D1, D0. ... D8 also note on box D0 shows at port 8;
// D0 (WHITE) is managed by wifi event hander (see setup();) and D8 is internet failure warning.
const int dPin[] = {5, 16, 4, 0, 2, 14, 12, 13, 15};

// PING MANAGEMENT
/* **********************    change these during testing!         ********** */
const long interval = 60000;   //60 seconds betwen successive rounds
const int nRounds = 60; //number of full rounds to complete before calling ntp & save to file: 60 rounds * interval (60 sec) = 1 hour

//const long interval = 6000;  //6 seconds between rounds
//const int nRounds = 10; //number of full rounds to complete before calling ntp & save to file: 10 rounds * interval (6 sec) = 1 min

int count = 1; // number of rounds completed:
bool roundComplete = 0; //flags all 1 round to a single target complete
bool isFinished; //flags 1 set of pingNumber pings to a single target
byte target = 0; //state machine control and selects url to ping
//int URL = 4; // *** if =4 uses LP to check operation of test;
int URL = 6; // =6 uses "theHut" service to check web availability

//handling ping results
int pingNumber = 2; //do 2 pings per set
int pingDelay = 200; //allow 200ms for response. 1 set takes <<1 sec.  (Solar monitor doesnt ping; all others OK)
int pingAvg, pingsLost; // recording ping statistics
float pingLossTotals[7], tPingTotals[7]; // to generate stats (spiffs tab) when ntp called
int t1Ping, t1PingSq; // time for 1 ping (=tPing/pingNumber); and its square.
float sigma; //st dev of ping time
unsigned long startTime = 0;  //recording millis() times & set to repeat every minute    (target 11)

//internet failure indication:
int warnLevel = 0; //total number of failed pings to talktalk
int warnThreshold = 100; // 12 * number of failed pings to talktalk  before a warning will be flagged
int warnLowThreshold = 24; //Level where the warning will be reset
int webGood = 0;  //set to zero if pings to web lost & back to 1 if ping successful
int webStatus = 0; //previous status - to check for a change

//time & date variables
char dayStamp[12], timeStamp[12]; //dayStamp = yyyy/mm/dd  Timestamp = hh/mm/ss
String myFormattedDate;
int YYYY, MM, DD, hh, mm, ss;  //integer values for current date and time
int today;  //check for day change to write new headline to file
int thisMonth; //check to see if we need to delete last years record for the same month
String lastYear; //to make filename for last years month file
String sYear, sMonth;  //name to build file for new month

//writing to serial and file on SPIFFS
String lostWait = " lost; wait; ";
String testServer = " test server";
String headLine; //heading line of text for writing to serial
String statsLine; //buffer for line of stats for serial
String fHeadLine; //heading line of text for writing to file
String fHeadLine1; //second heading line of text for writing to file
String fStatsLine; //buffer for line of stats for file

// WiFI, FTP

//WiFiUDP Udp;
//unsigned int localPort = 8888;  // local port to listen for UDP packets
WiFiEventHandler gotIpEventHandler, disconnectedEventHandler;
int WiFiState = 0; //condition of Wifi connection 0 off or 1 on
int WiFiUp = 0;     //record how much its up over nRounds
int WiFiPercent = 0;

FtpServer ftpSrv;   //set #define FTP_DEBUG in ESP8266FtpServer.h to see ftp verbose on serial


struct host {
  byte IP[4];
  int tPing;  //total time for pingNumber pings
  int nLost;  //number of lost pings
  char ipString[18]; // ip address for printing
  float tAvPing, nAvPing; //averages over hour for ping time, pingslost
  unsigned long tSp, tSpSq; //aggregated time for 1 ping and square of ping times
};

//create data set of type host, &  initialise our struct for all cases
  //{{192, 168, 1, 1}, 0, 0, "192.168.1.1" , 0, 0} , //router
  //{{192, 168, 1, 34}, 0, 0, "192.168.1.34" , 0, 0} , //Solar logger - doesnt respond to pings
host host1[7] = {
  {{192, 168, 1, 11}, 0, 0,  "192.168.1.11" , 0 , 0} , //0: RYZEN5
  {{192, 168, 1, 21}, 0, 0, "192.168.1.21" , 0 , 0} , //1: FILES1
  {{192, 168, 1, 14}, 0, 0, "192.168.1.14" , 0, 0} , //2: ALIVE-A6
  {{192, 168, 1, 24}, 0, 0, "192.168.1.24" , 0, 0} , //3: NAS
  {{192, 168, 1, 22}, 0, 0, "192.168.1.22" , 0 , 0} , //4: LP
  {{192, 168, 1, 42}, 0, 0, "192.168.1.42" , 0, 0} , //5: ESP32 test system
  {{185, 217, 104, 171}, 0, 0, "185.217.104.171" , 0 , 0} //6: TheHUT
};
